Module sfo_http::http_server
source · Modules
- Traits for conversions between types.
- Common types for HTTP operations.
- Types that represent HTTP transports and binding
- Event logging types.
- The Tide prelude.
- HTTP Security Headers.
- Tide session support
- Server-Sent Events (SSE) types.
- Miscellaneous utilities.
Structs
- A streaming HTTP body.
- The error type for HTTP operations.
- The remainder of a middleware chain, including the endpoint.
- A redirection endpoint.
- An HTTP request.
- An HTTP response
- Response Builder
- A handle to a route.
- An HTTP server.
Enums
- HTTP response status codes.
Traits
- An HTTP request handler.
- Middleware that wraps around the remaining middleware chain.
- Provides the
statusmethod forResultandOption.
Functions
- Create a new Tide server.
- Create a new Tide server with shared application scoped state.
Type Definitions
- A specialized Result type for Tide.