Struct sfo_http::http_server::http::Extensions
pub struct Extensions { /* private fields */ }Expand description
A type to store extra data inside Request and Response.
Store and retrieve values by
TypeId. This allows
storing arbitrary data that implements Sync + Send + 'static. This is
useful when for example implementing middleware that needs to send values.
Implementations
impl Extensions
impl Extensions
pub fn insert<T>(&mut self, val: T) -> Option<T>where
T: Send + Sync + 'static,
pub fn insert<T>(&mut self, val: T) -> Option<T>where T: Send + Sync + 'static,
Insert a value into this Extensions.
If a value of this type already exists, it will be returned.
pub fn get<T>(&self) -> Option<&T>where
T: 'static,
pub fn get<T>(&self) -> Option<&T>where T: 'static,
Get a reference to a value previously inserted on this Extensions.
pub fn get_mut<T>(&mut self) -> Option<&mut T>where
T: 'static,
pub fn get_mut<T>(&mut self) -> Option<&mut T>where T: 'static,
Get a mutable reference to a value previously inserted on this Extensions.
pub fn remove<T>(&mut self) -> Option<T>where
T: 'static,
pub fn remove<T>(&mut self) -> Option<T>where T: 'static,
Remove a value from this Extensions.
If a value of this type exists, it will be returned.
pub fn clear(&mut self)
pub fn clear(&mut self)
Clear the Extensions of all inserted values.