pub struct Redirect<T>where
    T: AsRef<str>,{ /* private fields */ }
A redirection endpoint.

Example

async fn route_handler(request: Request<()>) -> tide::Result {
    if let Some(product_url) = next_product() {
        Ok(Redirect::new(product_url).into())
    } else {
        //...
    }
}

Implementations

source

impl<T> Redirect<T>where T: AsRef<str>,

source

pub fn new(location: T) -> Redirect<T>

Creates an endpoint that represents a redirect to location.

Uses status code 302 Found.

source

pub fn permanent(location: T) -> Redirect<T>

Creates an endpoint that represents a permanent redirect to location.

Uses status code 301 Permanent Redirect.

source

pub fn temporary(location: T) -> Redirect<T>

Creates an endpoint that represents a temporary redirect to location.

Uses status code 307 Temporary Redirect.

source

pub fn see_other(location: T) -> Redirect<T>

Creates an endpoint that represents a see other redirect to location.

Uses status code 303 See Other.