Module sfo_http::http_util::codegen

source ·

Structs

  • In-Memory Generator, this uses a Vec to store the JSON result.
  • Pretty In-Memory Generator, this uses a Vec to store the JSON result and add indent.
  • Pretty Writer Generator, this uses a custom writer to store the JSON result and add indent.
  • Writer Generator, this uses a custom writer to store the JSON result.

Traits

  • Default trait for serializing JSONValue into string.