pub struct Object { /* private fields */ }
A binary tree implementation of a string -> JsonValue map. You normally don’t have to interact with instances of Object, much more likely you will be using the JsonValue::Object variant, which wraps around this struct.

Implementations

source

impl Object

source

pub fn new() -> Object

Create a new, empty instance of Object. Empty Object performs no allocation until a value is inserted into it.

source

pub fn with_capacity(capacity: usize) -> Object

Create a new Object with memory preallocated for capacity number of entries.

source

pub fn insert(&mut self, key: &str, value: JsonValue)

Insert a new entry, or override an existing one. Note that key has to be a &str slice and not an owned String. The internals of Object will handle the heap allocation of the key if needed for better performance.

source

pub fn override_last(&mut self, value: JsonValue)

👎Deprecated since 0.11.11: Was only meant for internal use
source

pub fn get(&self, key: &str) -> Option<&JsonValue>

source

pub fn get_mut(&mut self, key: &str) -> Option<&mut JsonValue>

source

pub fn remove(&mut self, key: &str) -> Option<JsonValue>

Attempts to remove the value behind key, if successful will return the JsonValue stored behind the key.

source

pub fn len(&self) -> usize

source

pub fn is_empty(&self) -> bool

source

pub fn clear(&mut self)

Wipe the Object clear. The capacity will remain untouched.

source

pub fn iter(&self) -> Iter<'_>

source

pub fn iter_mut(&mut self) -> IterMut<'_>

source

pub fn dump(&self) -> String

Prints out the value as JSON string.

source

pub fn pretty(&self, spaces: u16) -> String

Pretty prints out the value as JSON string. Takes an argument that’s number of spaces to indent new blocks with.