Struct sfo_http::http_server::Redirect
source · pub struct Redirect<T>where
T: AsRef<str>,{ /* private fields */ }Expand description
A redirection endpoint.
Example
async fn route_handler(request: Request<()>) -> tide::Result {
if let Some(product_url) = next_product() {
Ok(Redirect::new(product_url).into())
} else {
//...
}
}Implementations
sourceimpl<T> Redirect<T>where
T: AsRef<str>,
impl<T> Redirect<T>where T: AsRef<str>,
sourcepub fn new(location: T) -> Redirect<T>
pub fn new(location: T) -> Redirect<T>
Creates an endpoint that represents a redirect to location.
Uses status code 302 Found.
sourcepub fn permanent(location: T) -> Redirect<T>
pub fn permanent(location: T) -> Redirect<T>
Creates an endpoint that represents a permanent redirect to location.
Uses status code 301 Permanent Redirect.